==> phpsysinfo_2.5.1.orig.tar.gz: phpsysinfo/includes/lang/tr.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: tr.php,v 1.12 2005/12/07 15:02:11 bigmichi1 Exp $

$text['title']          = 'Sistem Bilgisi';

$text['vitals']         = 'Sistem Temel';
$text['hostname']       = 'Cannonical Host Adresi';
$text['ip']             = 'IP Adresi';
$text['kversion']       = 'Kernel Versiyonu';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Ak Kald Sre';
$text['users']          = 'u Andaki Kullanclar';
$text['loadavg']        = 'Ykleme Ortalamas';

$text['hardware']       = 'Hardware Bilgisi';
$text['numcpu']         = 'CPU Says';
$text['cpumodel']       = 'Model';
$text['cpuspeed']       = 'CPU Hz( Mhz)';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Cache Bykl';
$text['bogomips']       = 'Sistem Bogomips';

$text['pci']            = 'PCI Aralar';
$text['ide']            = 'IDE Aralar';
$text['scsi']           = 'SCSI Aralar';
$text['usb']            = 'USB Aralar';

$text['netusage']       = 'Network Kullanm';
$text['device']         = 'Arayz';
$text['received']       = 'Alnan';
$text['sent']           = 'Gnderilen';
$text['errors']         = 'Hata/Drlen';

$text['connections']    = 'Kurulmu Network Balantlar';

$text['memusage']       = 'Hafza Kullanm';
$text['phymem']         = 'Fiziksel Hafza';
$text['swap']           = 'Disk Swap';

$text['fs']             = 'Mount Edilmi Sistemler';
$text['mount']          = 'Mount';
$text['partition']      = 'Ksm';

$text['percent']        = 'Yzde Kapasite';
$text['type']           = 'Tr';
$text['free']           = 'Bo Alan';
$text['used']           = 'Kullanlan';
$text['size']           = 'Byklk';
$text['totals']         = 'Toplam';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'Hibiri';

$text['capacity']       = 'Kapasite';

$text['template']       = 'Arayz';
$text['language']       = 'Dil';
$text['submit']         = 'Gnder';
$text['created']        = 'Yaratan';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'gn';
$text['hours']          = 'saat';
$text['minutes']        = 'dakika';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= '- Kernel + applications';
$text['buffers']	= '- Buffers';
$text['cached']		= '- Cached';

?>

==> phpsysinfo_2.5.2.orig.tar.gz: phpsysinfo/includes/lang/tr.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: tr.php,v 1.14 2006/06/05 11:48:17 bigmichi1 Exp $

$text['title']          = 'Sistem Bilgisi';

$text['vitals']         = 'Sistem Temel';
$text['hostname']       = 'Cannonical Host Adresi';
$text['ip']             = 'IP Adresi';
$text['kversion']       = 'Kernel Versiyonu';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Ak Kald Sre';
$text['users']          = 'u Andaki Kullanclar';
$text['loadavg']        = 'Ykleme Ortalamas';

$text['hardware']       = 'Hardware Bilgisi';
$text['numcpu']         = 'CPU Says';
$text['cpumodel']       = 'Model';
$text['cpuspeed']       = 'CPU Hz( Mhz)';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Cache Bykl';
$text['bogomips']       = 'Sistem Bogomips';

$text['pci']            = 'PCI Aralar';
$text['ide']            = 'IDE Aralar';
$text['scsi']           = 'SCSI Aralar';
$text['usb']            = 'USB Aralar';

$text['netusage']       = 'Network Kullanm';
$text['device']         = 'Arayz';
$text['received']       = 'Alnan';
$text['sent']           = 'Gnderilen';
$text['errors']         = 'Hata/Drlen';

$text['connections']    = 'Kurulmu Network Balantlar';

$text['memusage']       = 'Hafza Kullanm';
$text['phymem']         = 'Fiziksel Hafza';
$text['swap']           = 'Disk Swap';

$text['fs']             = 'Mount Edilmi Sistemler';
$text['mount']          = 'Mount';
$text['partition']      = 'Ksm';

$text['percent']        = 'Yzde Kapasite';
$text['type']           = 'Tr';
$text['free']           = 'Bo Alan';
$text['used']           = 'Kullanlan';
$text['size']           = 'Byklk';
$text['totals']         = 'Toplam';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'Hibiri';

$text['capacity']       = 'Kapasite';

$text['template']       = 'Arayz';
$text['language']       = 'Dil';
$text['submit']         = 'Gnder';
$text['created']        = 'Yaratan';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'gn';
$text['hours']          = 'saat';
$text['minutes']        = 'dakika';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degreeC']        = '&ordm;C';
$text['degreeF']        = '&ordm;F';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

?>
